@@ -2,27 +2,40 @@
 # This file is part of AceQL Python Client SDK.
 # AceQL Python Client SDK: Remote SQL access over HTTP with AceQL HTTP.
 # Copyright (C) 2020,  KawanSoft SAS
-# (http://www.kawansoft.com). All rights reserved.                                
-#                                                                               
+# (http://www.kawansoft.com). All rights reserved.
+#
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
 # You may obtain a copy of the License at
-# 
+#
 #     http://www.apache.org/licenses/LICENSE-2.0
-# 
+#
 # Unless required by applicable law or agreed to in writing, software
 # distributed under the License is distributed on an "AS IS" BASIS,
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
-# limitations under the License. 
+# limitations under the License.
 ##
 import marshmallow_dataclass
 
-from aceql._private.user_login_store import *
+from aceql._private.file_util import FileUtil
+from aceql._private.user_login_store import UserLoginStore
 from aceql._private.jdbc_database_meta_data_dto import JdbcDatabaseMetaDataDto
 from aceql._private.table_dto import TableDto
 from aceql._private.table_names_dto import TableNamesDto
 
+import requests
+from requests_toolbelt.multipart import encoder
+
+from aceql._private.file_util import os
+from aceql.error import Error
+from aceql._private.aceql_debug import AceQLDebug
+from aceql._private.result_analyzer import ResultAnalyzer
+from aceql._private.result_set_info import ResultSetInfo
+from aceql._private.row_counter import RowCounter
+from aceql._private.stream_result_analyzer import StreamResultAnalyzer
+from aceql._private.version_values import VersionValues
+
 
 class AceQLHttpApi(object):
     """ AceQL HTTP wrapper for all apis. Takes care of all
@@ -104,7 +117,7 @@ class AceQLHttpApi(object):
 
                 user_login_store.set_session_id(session_id);
         except Exception as e:
-            if type(e) == Error:
+            if isinstance(e, Error):
                 raise
             else:
                 raise Error(str(e), 0, e, None, self.__http_status_code)
@@ -114,17 +127,17 @@ class AceQLHttpApi(object):
     # *
     # * @return {@code true} if session is stateless, else {@code false}.
     #
+    @staticmethod
     def is_stateless():
         return AceQLHttpApi.__stateless
 
-    is_stateless = staticmethod(is_stateless)
-
     # *
     # * Sets the session mode
     # *
     # * @param stateless
     # * if true, the session will be stateless, else stateful.
     #
+    @staticmethod
     def set_stateless(the_stateless):
         if the_stateless is None:
             raise TypeError("stateless is null!")
@@ -133,18 +146,15 @@ class AceQLHttpApi(object):
         else:
             AceQLHttpApi.__stateless = False
 
-    set_stateless = staticmethod(set_stateless)
-
     # *
     # * Sets the timeout in seconds
     #
+    @staticmethod
     def set_timeout(timeout):
         if timeout is None:
             raise TypeError("timeout is null!")
         AceQLHttpApi.__timeout = timeout
 
-    set_timeout = staticmethod(set_timeout)
-
     def set_progress_indicator(self, progress_indicator):
         self.__progress_indicator = progress_indicator
 
@@ -194,10 +204,10 @@ class AceQLHttpApi(object):
                 raise Error(result_analyzer.get_error_message(),
                             result_analyzer.get_error_type(), None, None, self.__http_status_code)
 
-            return result_analyzer.get_result()
+            return result_analyzer.get_result_default()
 
         except Exception as e:
-            if type(e) == Error:
+            if isinstance(e, Error):
                 raise
             else:
                 raise Error(str(e), 0, e, None, self.__http_status_code)
@@ -215,7 +225,7 @@ class AceQLHttpApi(object):
                             result_analyzer.get_error_type(), None, None, self.__http_status_code)
 
         except Exception as e:
-            if type(e) == Error:
+            if isinstance(e, Error):
                 raise
             else:
                 raise Error(str(e), 0, e, None, self.__http_status_code)
@@ -243,11 +253,8 @@ class AceQLHttpApi(object):
     def rollback(self):
         self.call_api_no_result("rollback", None)
 
-    def trace(self):
-        if AceQLHttpApi.__trace_on:
-            print()
-
-    def trace(self, s):
+    @staticmethod
+    def trace(s):
         if AceQLHttpApi.__trace_on:
             print(s)
 
@@ -256,22 +263,20 @@ class AceQLHttpApi(object):
     # *
     # * @return true if trace is on
     #
+    @staticmethod
     def is_trace_on():
         return AceQLHttpApi.__trace_on
 
-    is_trace_on = staticmethod(is_trace_on)
-
     # *
     # * Sets the trace on/off
     # *
     # * @param TRACE_ON
     # * if true, trace will be on
     #
+    @staticmethod
     def set_trace_on(trace_on):
         AceQLHttpApi.__trace_on = trace_on
 
-    set_trace_on = staticmethod(set_trace_on)
-
     # *
     # * @return the prettyPrinting
     #
@@ -324,7 +329,8 @@ class AceQLHttpApi(object):
     # * @
     # * if any Exception occurs
     #
-    def get_client_version(self):
+    @staticmethod
+    def get_client_version():
         return VersionValues.NAME + " - " + VersionValues.VERSION + " - " + VersionValues.DATE
 
     # *
@@ -526,7 +532,7 @@ class AceQLHttpApi(object):
             return row_count
 
         except Exception as e:
-            if type(e) == Error:
+            if isinstance(e, Error):
                 raise
             else:
                 raise Error(str(e), 0, e, None, self.__http_status_code)
@@ -617,6 +623,7 @@ class AceQLHttpApi(object):
             if self.is_gzip_result():
                 file_out = filename[0: len(filename) - 4] + ".ungzipped.txt"
                 FileUtil.decompress(filename, file_out)
+                from aceql import Parms
                 if Parms.DELETE_FILES:
                     os.remove(filename)
             else:
@@ -640,7 +647,7 @@ class AceQLHttpApi(object):
             return result_set_info
 
         except Exception as e:
-            if type(e) == Error:
+            if isinstance(e, Error):
                 raise
             else:
                 raise Error(str(e), 0, e, None, self.__http_status_code)
@@ -665,7 +672,7 @@ class AceQLHttpApi(object):
             return response
 
         except Exception as e:
-            if type(e) == Error:
+            if isinstance(e, Error):
                 raise
             else:
                 raise Error(str(e), 0, e, None, self.__http_status_code)
@@ -696,7 +703,7 @@ class AceQLHttpApi(object):
             return response
 
         except Exception as e:
-            if type(e) == Error:
+            if isinstance(e, Error):
                 raise
             else:
                 raise Error(str(e), 0, e, None, self.__http_status_code)
@@ -741,7 +748,7 @@ class AceQLHttpApi(object):
             return int(length_str)
 
         except Exception as e:
-            if type(e) == Error:
+            if isinstance(e, Error):
                 raise
             else:
                 raise Error(str(e), 0, e, None, self.__http_status_code)
@@ -761,7 +768,6 @@ class AceQLHttpApi(object):
 
         except Exception as e:
             print(str(e))
-            pass
 
     def blob_upload(self, blob_id, fd, total_length):
         """ Upload the BLOB and use a callback function for progress indicator. """
@@ -779,8 +785,8 @@ class AceQLHttpApi(object):
         m = encoder.MultipartEncoderMonitor(e, self.my_callback)
 
         the_url = self._url + "blob_upload"
-        r = requests.post(the_url, data=m, headers={'Content-Type': m.content_type}, proxies=self.__proxies,
-                          auth=self.__auth)
+        requests.post(the_url, data=m, headers={'Content-Type': m.content_type}, proxies=self.__proxies,
+                      auth=self.__auth)
 
     def get_db_metadata(self):
         try:
@@ -805,7 +811,7 @@ class AceQLHttpApi(object):
             return jdbc_database_meta_data_holder;
 
         except Exception as e:
-            if type(e) == Error:
+            if isinstance(e, Error):
                 raise
             else:
                 raise Error(str(e), 0, e, None, self.__http_status_code)
@@ -836,7 +842,7 @@ class AceQLHttpApi(object):
             return table_names_dto;
 
         except Exception as e:
-            if type(e) == Error:
+            if isinstance(e, Error):
                 raise
             else:
                 raise Error(str(e), 0, e, None, self.__http_status_code)
@@ -868,7 +874,7 @@ class AceQLHttpApi(object):
             return table_dto;
 
         except Exception as e:
-            if type(e) == Error:
+            if isinstance(e, Error):
                 raise
             else:
                 raise Error(str(e), 0, e, None, self.__http_status_code)
