@@ -3,72 +3,37 @@
 # This file is part of AceQL Python Client SDK.
 # AceQL Python Client SDK: Remote SQL access over HTTP with AceQL HTTP.
 # Copyright (C) 2020,  KawanSoft SAS
-# (http://www.kawansoft.com). All rights reserved.                                
-#                                                                               
+# (http://www.kawansoft.com). All rights reserved.
+#
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
 # You may obtain a copy of the License at
-# 
+#
 #     http://www.apache.org/licenses/LICENSE-2.0
-# 
+#
 # Unless required by applicable law or agreed to in writing, software
 # distributed under the License is distributed on an "AS IS" BASIS,
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
-# limitations under the License. 
+# limitations under the License.
 ##
 
-import aceql
-from aceql import *
-
+from aceql import Connection
+from aceql import ProgressIndicator
+from aceql import SqlNullType
 import unittest
-import sys
 import os
 from os import sep
 from datetime import datetime, date
+from tests.connection_builder import ConnectionBuilder
 
 
 class TestAll(unittest.TestCase):
     def test_A(self):
-        print(sys.version)
-        # assert sys.version_info >= (2,5)
+
+        connection = ConnectionBuilder.get_connection()
         print()
-
-        print("aceql.apilevel    : " + aceql.apilevel)
-        print("aceql.threadsafety: " + str(aceql.threadsafety))
-        print("aceql.paramstyle  : " + aceql.paramstyle)
-
-        proxies = None
-        auth = None
-
-        use_proxy  = False
-        if use_proxy:
-            proxies = {
-                "http": "http://localhost:8080",
-            }
-
-            auth = TestAll.getProxyAuth()
-
-        localhost = "http://localhost:9090/aceql"
-        server_host = "https://www.aceql.com:9443/aceql"
-        server_host_no_ssl = "http://www.aceql.com:9090/aceql"
-
-        host = localhost
-        database = "sampledb"
-        username= "user1"
-
-        password= "password1"
-        session_id = None
-        #password= None
-        #session_id = "3j7aoduuekz3r8qdzyb2lc9plj"
-
-        Connection.set_timeout(10)
-        Connection.set_stateless(False)
-        connection = aceql.connect(host, database, username, password, session_id, proxies=proxies, auth=auth)
-        connection.set_gzip_result(True)
-
-        print()
-        print("aceql version: " + connection.get_client_version())
+        print("aceql version: " + Connection.get_client_version())
         print()
 
         connection.set_holdability("hold_cursors_over_commit")
@@ -211,21 +176,12 @@ class TestAll(unittest.TestCase):
         cursor.close()
 
         connection.close()
-        connection2 = aceql.connect(host, "sampledb", "user1", "password1", proxies=proxies, auth=auth)
+        connection2 = ConnectionBuilder.get_connection()
         print("connection2.get_auto_commit(): " + str(connection2.get_auto_commit()))
         print()
         connection2.logout()
         print()
 
-    @staticmethod
-    def getProxyAuth():
-        """Get proxy auth info from a filename"""
-        with open("I:\\neotunnel.txt", "rt") as fd:
-            content = fd.read()
-        lines = content.split()
-        auth = ProxyAuth(lines[0].strip(), lines[1].strip())
-        return auth
-
 
 if __name__ == '__main__':
     unittest.main()
